@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2004 Gentoo Technologies, Inc.
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-src/rc-scripts/sbin/runscript.sh,v 1.33 2004/07/10 03:37:29 agriffis Exp $
+# $Header: /var/cvsroot/gentoo-src/rc-scripts/sbin/runscript.sh,v 1.36 2004/08/18 20:35:37 agriffis Exp $
 
 # Common functions
 [ "${RC_GOT_FUNCTIONS}" != "yes" ] && source /sbin/functions.sh
@@ -360,7 +360,7 @@ svc_restart() {
 }
 
 svc_status() {
-	# The basic idea here is to have some sort of consistant
+	# The basic idea here is to have some sort of consistent
 	# output in the status() function which scripts can use
 	# as an generic means to detect status.  Any other output
 	# should thus be formatted in the custom status() function
@@ -386,7 +386,8 @@ svc_status() {
 	status
 }
 
-wrap_rcscript "${myscript}" || {
+rcscript_errors=$(wrap_rcscript "${myscript}" 2>&1) || {
+	[[ -n ${rcscript_errors} ]] && echo "${rcscript_errors}" >&2
 	eerror "ERROR:  \"${myscript}\" has syntax errors in it; not executing..."
 	exit 1
 }
@@ -453,11 +454,9 @@ do
 	case "${arg}" in
 	stop)
 		svc_stop
-		rc_splash_update "live" "${myservice}" "stop"
 		;;
 	start)
 		svc_start
-		rc_splash_update "live" "${myservice}" "start"
 		;;
 	needsme|ineed|usesme|iuse|broken)
 		list_depend_trace "${arg}"
